#
# spec file for package perl-SDL
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name SDL
Name:           perl-SDL
Version:        2.548
Release:        8.5
License:        LGPL-2.1-or-later
Summary:        SDL bindings to Perl
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/F/FR/FROGGS/%{cpan_name}-%{version}.tar.gz
Source1:        perl-SDL.rpmlintrc
Source2:        cpanspec.yml
# PATCH-FIX-UPSTREAM 299.patch -- based on PR 299
Patch0:         https://patch-diff.githubusercontent.com/raw/PerlGameDev/SDL/pull/299.patch
# PATCH-FIX-UPSTREAM 304.patch -- based on PR 304
Patch1:         https://patch-diff.githubusercontent.com/raw/PerlGameDev/SDL/pull/304.patch
# PATCH-FIX-UPSTREAM 308.patch -- based on PR 308
Patch2:         https://patch-diff.githubusercontent.com/raw/PerlGameDev/SDL/pull/308.patch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Alien::SDL) >= 1.446
BuildRequires:  perl(CPAN) >= 1.92
BuildRequires:  perl(Capture::Tiny)
BuildRequires:  perl(ExtUtils::CBuilder) >= 0.260301
BuildRequires:  perl(File::ShareDir) >= 1.0
BuildRequires:  perl(Module::Build) >= 0.400000
BuildRequires:  perl(Test::Most) >= 0.21
BuildRequires:  perl(Test::Simple) >= 0.88
BuildRequires:  perl(Tie::Simple)
Requires:       perl(CPAN) >= 1.92
Requires:       perl(File::ShareDir) >= 1.0
Requires:       perl(Tie::Simple)
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  Mesa-devel
BuildRequires:  libSDL-devel
BuildRequires:  libSDL_Pango-devel
BuildRequires:  libSDL_gfx-devel
BuildRequires:  libSDL_image-devel
BuildRequires:  libSDL_mixer-devel
BuildRequires:  libSDL_net-devel
BuildRequires:  libSDL_sound-devel
BuildRequires:  libSDL_ttf-devel
# Tests: dejavu-fonts required by t/pango.t, udev required by t/core_joystick.t
BuildRequires:  dejavu-fonts
BuildRequires:  udev
# MANUAL END

%description
SDL Perl are a set of bindings to the Simple DirectMedia Layer (SDL).

Simple DirectMedia Layer is a cross-platform multimedia library designed to
provide low level access to audio, keyboard, mouse, joystick, 3D hardware via
OpenGL, and 2D video framebuffer. It is used by MPEG playback software,
emulators, and many popular games, including the award winning Linux port of
"Civilization: Call To Power."

%prep
%autosetup  -n %{cpan_name}-%{version} -p1

# MANUAL BEGIN
%ifarch %arm ppc64 ppc64le s390x
# Remove hanging test. See: https://github.com/PerlGameDev/SDL/issues/289
rm t/sdlx_controller_interface.t
%endif
# core_video is deadlocking in OBS builds (no graphical interface available)
rm t/core_video.t
# MANUAL END

%build
perl Build.PL --installdirs=vendor optimize="%{optflags}"
./Build build --flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install --destdir=%{buildroot} --create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%doc CHANGELOG examples OFL-FAQ.txt OFL.txt TODO
%license COPYING

%changelog
* Wed May  1 2024 munix9@googlemail.com
- Add 299.patch: Fix implicit declaration of _calc_offset,
  also required for gcc 14 (gh#PerlGameDev/SDL#299).
* Mon Apr 15 2024 munix9@googlemail.com
- Add 308.patch: Fix reference-counting in set_event_filter
  (gh#PerlGameDev/SDL#308).
* Tue Aug  8 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add 304.patch: Fix build with Perl 5.35 (gh#PerlGameDev/SDL#304).
* Fri Jan 13 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Skip t/core_video.t: We do not have a GUI available inside OBS
  builds which can result in this test deadlocking.
* Tue Aug 16 2022 Dirk Stoecker <opensuse@dstoecker.de>
- updated cpanspec.yml
* Tue Aug 16 2022 munix9@googlemail.com
- Add dejavu-fonts and udev as BuildRequires for tests
* Fri Feb  7 2020 Berthold Gunreben <azouhr@opensuse.org>
- Remove hanging tests on s390x: 't/sdlx_controller_interface.t'
* Wed Nov 28 2018 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Remove hanging tests on %%arm and ppc64*: 't/sdlx_controller_interface.t'
* Sun Oct  7 2018 Dirk Stoecker <opensuse@dstoecker.de>
- Fix autogenerated changes
* Sun May 20 2018 coolo@suse.com
- updated to 2.548
  see /usr/share/doc/packages/perl-SDL/CHANGELOG
  * 2.548 May 19 2018
  - Add version number to all modules [FROGGS]
* Wed Feb  7 2018 coolo@suse.com
- updated to 2.546
  see /usr/share/doc/packages/perl-SDL/CHANGELOG
* Mon Jun  9 2014 stephan.barth@suse.com
- refined rpmlintrc to be Perl version and arch independent
* Wed Jun  4 2014 stephan.barth@suse.com
- Added perl-SDL.rpmlintrc as a source to the spec file
* Fri May 30 2014 stephan.barth@suse.com
- Added perl-SDL.rpmlintrc for empty bootstrap files in
  /usr/lib/perl5/vendor_perl/5.18.2/x86_64-linux-thread-multi/auto/
- Update to version 2.544 from 2.540
  - Updated Alien::SDL's version we depend on to get an OpenBSD/pthread
    fix [FROGGS]
  - Fix segfault in cleanup of MixChunks on windows [FROGGS]
  - Adjusting test for SDL_gfx >= 2.0.24 [FROGGS]
- Changed source URL to
  http://search.cpan.org/CPAN/authors/id/F/FR/FROGGS/SDL-%%{version}.tar.gz
  because of new upstream author
* Thu Nov 15 2012 cfarrell@suse.com
- license update: LGPL-2.1+ and OFL-1.1
* Wed Sep 19 2012 opensuse@dstoecker.de
- update to 2.540
* Tue Dec  7 2010 coolo@novell.com
- remove packlist with -f to fix build on 11.4
* Sun Jan 10 2010 ro@suse.de
- rediff path for fuzz=0
* Fri Nov 27 2009 prusnak@suse.cz
- updated to 2.2.6
  - Garu added a preview of SDL::Game::Rect
  - Garu fixed up LunarLander Tutorial
  - Kartik and Garu made a Pong preview for YAPC::Brasil
  - Last release of this API to provide newcomers with Pong and LunarLander Tutorial
  THIS IS THE LAST RELEASE OF THIS API.
* Tue Oct 20 2009 prusnak@suse.cz
- updated to 2.2.3.1
  - fixes broken frozen-bubble [bnc#548122]
  - Critical Build.PL fix for META.yml
  - Moved Debian patches upstream
  - Made App loop() faster
  - Patched support for add support for gluquadric* sub
  - Made App init slimer
  - Added faster SDL::Color alternative
  - Added better error reporting for TTFont errors
  - Fixed constants with help from arodland
  - Added warning instead of die for frozenbubble's sake
  - fixed undef access to blit in Surface
  - made sdl font strict acceptable
- drop obsoleted patch warning-fix.patch (in mainline)
* Thu Oct  8 2009 prusnak@suse.cz
- fix build failure
* Wed Oct  7 2009 prusnak@suse.cz
- fix provides and obsoletes [bnc#544957]
* Sat Aug  8 2009 prusnak@suse.cz
- updated to 2.2.0
  - added .spl file type for SDLPerl applications!
  - fixed build after Module::Build breakage
  - fixed openGL header problems
  - finished embedding data in example scripts
  - fixed bug where SDL::App frees underlying Surface via DESTROY
  - added SDL_svg support
  - cleaned up SDL_gfx support in SDL.xs
  - cleaned up smpeg support in SDL.xs
  - added more SDL_sound support
  - added basic SDL_RWops support (TODO - perl callback for user defined)
  - changed constructors to die upon invalid initialization
* Wed May 20 2009 prusnak@suse.cz
- follow Perl packages naming policy (renamed to perl-SDL_Perl)
* Mon May  5 2008 sndirsch@suse.de
- perl-5.10.0.diff
  * NULL has been added to POSIX module; adjusted definition to
    resolve the conflict (bnc #386412)
* Sat Mar 15 2008 sndirsch@suse.de
- update to release 2.1.3 (bnc #371318)
* Fri Aug 17 2007 sndirsch@suse.de
- fixed Buildrequires for SDL_net/SDL_ttf (Bug #301337)
* Mon Mar 12 2007 sndirsch@suse.de
- warning-fix.diff:
  * fixed compiler warning "array subscript is above array bounds"
    (Bug #253482)
* Fri Sep  8 2006 sndirsch@suse.de
- fixed build in openSUSE buildservice
* Thu Feb  2 2006 sndirsch@suse.de
- added Mesa-devel to BuildRequires to enable OpenGL support again
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Aug 20 2005 sndirsch@suse.de
- added SDL_mixer-devel + libmikmod to #neededforbuild, which
  enables SDL_mixer support again --> fixes sound support in
  frozen-bubble (Bug #106012)
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr
* Wed Aug 20 2003 mjancar@suse.cz
- require the perl version we build with
* Mon Aug 18 2003 sndirsch@suse.de
- downgraded to release 1.20 again as frozen-bubble no longer
  worked :-(
* Sat Aug 16 2003 sndirsch@suse.de
- updated to release 2.0
* Mon Jul 14 2003 mls@suse.de
- fixed build
* Sat Jul 12 2003 sndirsch@suse.de
- fixed build
* Fri Jun 13 2003 sndirsch@suse.de
- fixed filelist
* Sun May 25 2003 sndirsch@suse.de
- removed unpackaged files
* Fri May 23 2003 coolo@suse.de
- use BuildRoot
* Sun Jan 19 2003 sndirsch@suse.de
- updated to release 1.20.0
* Sun Dec 29 2002 sndirsch@suse.de
- updated to release 1.19.1
* Fri Oct 25 2002 sndirsch@suse.de
- fixed %%files section (use macros now)
* Thu Oct 24 2002 sndirsch@suse.de
- created package
